{% extends "base.html" %}
{% load granadilla_tags %}
{% load i18n staticfiles %}

{% block title %}{% block subtitle %}{% endblock %} | {% granadilla_title %}{% endblock %}

{% block headextra %}
<link rel="stylesheet" type="text/css" href="{% static "granadilla/css/granadilla.css" %}" />
{% endblock %}

{% block branding %}<h1 id="site-name">{% autoescape off %}{% granadilla_version %}{% endautoescape %}</h1>{% endblock %}

{% block related %}
<div class="module">
<h2>{% granadilla_title %}</h2>
<ul>
  <li class="phonebook-user"><a href="{% url "granadilla:index" %}">{% trans "Users" %}</a></li>
  <li class="phonebook-group"><a href="{% url "granadilla:groups" %}">{% trans "Groups" %}</a></li>
  <li class="phonebook-device"><a href="{% url "granadilla:device_list" %}">{% trans "Devices" %}</a></li>
  <li class="password-change"><a href="{% url "granadilla:change_password" %}">{% trans "Change password" %}</a></li>
{% block links %}{% endblock %}
</ul>
</div>
{% endblock %}
