{% extends "granadilla/device_base.html" %}
{% load i18n %}

{% block content %}

{% if password %} 

<h1>{% blocktrans %} Generated password for {{ device.login }}{% endblocktrans %}</h1>
{% trans "The device's password is now: " %} {{ password }}

{% else %}
<form method="post">
    {% csrf_token %}
    <input type="submit" value="{% trans "Generate new password" %}" />
</form>
{% endif %}

<a href="{% url "granadilla:device_list" %}">{% trans "Back to the device list" %}</a>

{% endblock %}
