{% extends "granadilla/base.html" %}
{% load granadilla_tags %}
{% load i18n %}

{% block subtitle %} {{user.username}} {% endblock %}

{% block breadcrumbs %}<a href="{% url "granadilla:index" %}">{% granadilla_title %}</a> &rsaquo; {{user.username}} &rsaquo; {% trans "Password change" %} {% endblock %}

{% block headextra %}
<link rel="stylesheet" media="screen" href="http://netdna.bootstrapcdn.com/bootstrap/3.0.0/css/bootstrap.min.css" />
<script src="http://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js" type="text/javascript"></script>
{% endblock %}

{% block content %}

<form action="" method= "POST">
<table class="modulepass">
{% csrf_token %}
<caption>{{ user.username }}</caption>
		<tr>
			{{form}}
			{{ form.media }}
		</tr>
		<tr>
			<td>&nbsp;</td> <td><input id="buttonpassword" type="submit" value="{% trans "Change password" %}"> </td>
		</tr>

</table>
</form>

{% endblock %}
